@@ -158,6 +158,8 @@ int qjackctlAlsaClientList::updateClientPorts (void)
     int iDirtyCount = 0;
 
     markClientPorts(0);
+    
+#ifdef CONFIG_ALSA_SEQ
 
     unsigned int uiAlsaFlags;
     if (isReadable())
@@ -185,17 +187,26 @@ int qjackctlAlsaClientList::updateClientPorts (void)
                     ((uiPortCapability & SND_SEQ_PORT_CAP_NO_EXPORT) == 0)) {
                     qjackctlAlsaPort *pPort = 0;
                     int iAlsaPort = snd_seq_port_info_get_port(pPortInfo);
-                    if (pClient)
-                        pPort = pClient->findPort(iAlsaPort);
+                    QString sClientName = snd_seq_client_info_get_name(pClientInfo);
                     if (pClient == 0) {
-                        QString sClientName = snd_seq_client_info_get_name(pClientInfo);
                         pClient = new qjackctlAlsaClient(this, sClientName, iAlsaClient);
                         iDirtyCount++;
+                    } else {
+                        pPort = pClient->findPort(iAlsaPort);
+                        if (sClientName != pClient->clientName()) {
+                            pClient->setClientName(sClientName);
+                            iDirtyCount++;
+                        }
                     }
-                    if (pClient && pPort == 0) {
+                    if (pClient) {
                         QString sPortName = snd_seq_port_info_get_name(pPortInfo);
-                        pPort = new qjackctlAlsaPort(pClient, sPortName, iAlsaPort);
-                        iDirtyCount++;
+                        if (pPort == 0) {
+                            pPort = new qjackctlAlsaPort(pClient, sPortName, iAlsaPort);
+                            iDirtyCount++;
+                        } else if (sPortName != pPort->portName()) {
+                            pPort->setPortName(sPortName);
+                            iDirtyCount++;
+                        }
                     }
                     if (pPort)
                         pPort->markClientPort(1);
@@ -203,6 +214,8 @@ int qjackctlAlsaClientList::updateClientPorts (void)
             }
         }
     }
+    
+#endif	// CONFIG_ALSA_SEQ
 
     cleanClientPorts(0);
 
@@ -269,6 +282,8 @@ snd_seq_t *qjackctlAlsaConnect::alsaSeq (void)
 // Connection primitive.
 void qjackctlAlsaConnect::connectPorts ( qjackctlPortItem *pOPort, qjackctlPortItem *pIPort )
 {
+#ifdef CONFIG_ALSA_SEQ
+
     qjackctlAlsaPort *pOAlsa = (qjackctlAlsaPort *) pOPort;
     qjackctlAlsaPort *pIAlsa = (qjackctlAlsaPort *) pIPort;
 
@@ -286,12 +301,16 @@ void qjackctlAlsaConnect::connectPorts ( qjackctlPortItem *pOPort, qjackctlPortI
     snd_seq_port_subscribe_set_dest(pAlsaSubs, &seq_addr);
 
     snd_seq_subscribe_port(m_pAlsaSeq, pAlsaSubs);
+
+#endif	// CONFIG_ALSA_SEQ
 }
 
 
 // Disconnection primitive.
 void qjackctlAlsaConnect::disconnectPorts ( qjackctlPortItem *pOPort, qjackctlPortItem *pIPort )
 {
+#ifdef CONFIG_ALSA_SEQ
+
     qjackctlAlsaPort *pOAlsa = (qjackctlAlsaPort *) pOPort;
     qjackctlAlsaPort *pIAlsa = (qjackctlAlsaPort *) pIPort;
 
@@ -309,12 +328,16 @@ void qjackctlAlsaConnect::disconnectPorts ( qjackctlPortItem *pOPort, qjackctlPo
     snd_seq_port_subscribe_set_dest(pAlsaSubs, &seq_addr);
 
     snd_seq_unsubscribe_port(m_pAlsaSeq, pAlsaSubs);
+
+#endif	// CONFIG_ALSA_SEQ
 }
 
 
 // Update port connection references.
 void qjackctlAlsaConnect::updateConnections (void)
 {
+#ifdef CONFIG_ALSA_SEQ
+
     snd_seq_query_subscribe_t *pAlsaSubs;
     snd_seq_addr_t seq_addr;
 
@@ -354,6 +377,8 @@ void qjackctlAlsaConnect::updateConnections (void)
             }
         }
     }
+
+#endif	// CONFIG_ALSA_SEQ
 }
 
 
