@@ -35,12 +35,10 @@ void qjackctlPatchbayForm::init (void)
     // Create the patchbay view object.
     m_pPatchbay = new qjackctlPatchbay(PatchbayView);
     m_iUntitled = 0;
-    
+
     // Connect it to some UI feedback slot.
-    QObject::connect(PatchbayView->OListView(), SIGNAL(selectionChanged(QListViewItem *)), this, SLOT(stabilizeForm()));
-    QObject::connect(PatchbayView->IListView(), SIGNAL(selectionChanged(QListViewItem *)), this, SLOT(stabilizeForm()));
-    QObject::connect(PatchbayView->OListView(), SIGNAL(currentChanged(QListViewItem *)), this, SLOT(stabilizeForm()));
-    QObject::connect(PatchbayView->IListView(), SIGNAL(currentChanged(QListViewItem *)), this, SLOT(stabilizeForm()));
+    QObject::connect(PatchbayView->OListView(), SIGNAL(selectionChanged()), this, SLOT(stabilizeForm()));
+    QObject::connect(PatchbayView->IListView(), SIGNAL(selectionChanged()), this, SLOT(stabilizeForm()));
     // Dirty patchbay dispatcher (stabilization deferral).
     QObject::connect(PatchbayView, SIGNAL(contentsChanged()), this, SLOT(contentsChanged()));
 
@@ -144,29 +142,33 @@ void qjackctlPatchbayForm::stabilizeForm ( void )
     qjackctlSocketItem *pSocketItem = (m_pPatchbay->OSocketList())->selectedSocketItem();
     if (pSocketItem) {
         OSocketEditPushButton->setEnabled(true);
+        OSocketCopyPushButton->setEnabled(true);
         OSocketRemovePushButton->setEnabled(true);
         OSocketMoveUpPushButton->setEnabled(pSocketItem->itemAbove() != NULL);
         OSocketMoveDownPushButton->setEnabled(pSocketItem->nextSibling() != NULL);
     } else {
         OSocketEditPushButton->setEnabled(false);
+        OSocketCopyPushButton->setEnabled(false);
         OSocketRemovePushButton->setEnabled(false);
         OSocketMoveUpPushButton->setEnabled(false);
         OSocketMoveDownPushButton->setEnabled(false);
     }
-    
+
     pSocketItem = (m_pPatchbay->ISocketList())->selectedSocketItem();
     if (pSocketItem) {
         ISocketEditPushButton->setEnabled(true);
+        ISocketCopyPushButton->setEnabled(true);
         ISocketRemovePushButton->setEnabled(true);
         ISocketMoveUpPushButton->setEnabled(pSocketItem->itemAbove() != NULL);
         ISocketMoveDownPushButton->setEnabled(pSocketItem->nextSibling() != NULL);
     } else {
         ISocketEditPushButton->setEnabled(false);
+        ISocketCopyPushButton->setEnabled(false);
         ISocketRemovePushButton->setEnabled(false);
         ISocketMoveUpPushButton->setEnabled(false);
         ISocketMoveDownPushButton->setEnabled(false);
     }
-    
+
     ConnectPushButton->setEnabled(m_pPatchbay->canConnectSelected());
     DisconnectPushButton->setEnabled(m_pPatchbay->canDisconnectSelected());
     DisconnectAllPushButton->setEnabled(m_pPatchbay->canDisconnectAll());
@@ -233,7 +235,7 @@ void qjackctlPatchbayForm::savePatchbayFile ( const QString& sFileName )
     m_sPatchbayPath = sFileName;
     m_sPatchbayName = QFileInfo(sFileName).baseName();
     stabilizeForm();
-    
+
     // Step 4: notify main form if applicable ...
     qjackctlMainForm *pMainForm = (qjackctlMainForm *) QWidget::parentWidget();
     if (pMainForm && pMainForm->isActivePatchbay(m_sPatchbayPath))
@@ -244,15 +246,26 @@ void qjackctlPatchbayForm::savePatchbayFile ( const QString& sFileName )
 // Create a new patchbay definition from scratch.
 void qjackctlPatchbayForm::newPatchbay()
 {
-    // Ask for a snapshot for scratch...
+    // Assume a snapshot from scratch...
     bool bSnapshot = false;
-    if (m_pPatchbay->jackClient() || m_pPatchbay->alsaSeq()) {
-        bSnapshot = (QMessageBox::information(this,
-            tr("New Patchbay definition"),
-            tr("Create patchbay definition as a snapshot") + "\n" +
-            tr("of all actual client connections?"),
-            tr("Yes"), tr("No")) == 0);
-    }
+
+	// Ask user what he/she wants to do...
+	if (m_pPatchbay->jackClient() || m_pPatchbay->alsaSeq()) {
+		switch (QMessageBox::information(this,
+			tr("New Patchbay definition"),
+			tr("Create patchbay definition as a snapshot") + "\n" +
+			tr("of all actual client connections?"),
+			tr("Yes"), tr("No"), tr("Cancel"))) {
+		case 0:		// Yes.
+			bSnapshot = true;
+			break;
+		case 1:		// No.
+			bSnapshot = false;
+			break;
+		default:	// Cancel.
+			return;
+		}
+	}
 
     // Check if we can discard safely the current one...
     if (!queryClose())
@@ -272,7 +285,7 @@ void qjackctlPatchbayForm::loadPatchbay()
             this, 0,                                        // Parent and name (none)
             tr("Load Patchbay Definition")                  // Caption.
     );
-    
+
     if (sFileName.isEmpty())
         return;
 
@@ -294,14 +307,14 @@ void qjackctlPatchbayForm::savePatchbay()
             this, 0,                                        // Parent and name (none)
             tr("Save Patchbay Definition")                  // Caption.
     );
-    
+
     if (sFileName.isEmpty())
         return;
-        
+
     // Enforce .xml extension...
     if (QFileInfo(sFileName).extension().isEmpty())
         sFileName += ".xml";
-    
+
     // Save it right away.
     savePatchbayFile(sFileName);
 }
@@ -355,6 +368,12 @@ void qjackctlPatchbayForm::editOSocket()
 }
 
 
+void qjackctlPatchbayForm::copyOSocket()
+{
+    (m_pPatchbay->OSocketList())->copySocketItem();
+}
+
+
 void qjackctlPatchbayForm::moveUpOSocket()
 {
     (m_pPatchbay->OSocketList())->moveUpSocketItem();
@@ -387,6 +406,12 @@ void qjackctlPatchbayForm::editISocket()
 }
 
 
+void qjackctlPatchbayForm::copyISocket()
+{
+    (m_pPatchbay->ISocketList())->copySocketItem();
+}
+
+
 void qjackctlPatchbayForm::moveUpISocket()
 {
     (m_pPatchbay->ISocketList())->moveUpSocketItem();
