@@ -22,6 +22,8 @@
 #include "qjackctlSetup.h"
 #include "qjackctlAbout.h"
 
+#include <qtimer.h>
+
 
 // Constructor.
 qjackctlSetup::qjackctlSetup (void)
@@ -74,6 +76,7 @@ qjackctlSetup::qjackctlSetup (void)
     bQueryClose              = m_settings.readBoolEntry("/QueryClose", true);
     bKeepOnTop               = m_settings.readBoolEntry("/KeepOnTop", true);
     bSystemTray              = m_settings.readBoolEntry("/SystemTray", false);
+    bDelayedSetup            = m_settings.readBoolEntry("/DelayedSetup", false);
     bServerConfig            = m_settings.readBoolEntry("/ServerConfig", true);
     sServerConfigName        = m_settings.readEntry("/ServerConfigName", ".jackdrc");
     bServerConfigTemp        = m_settings.readBoolEntry("/ServerConfigTemp", false);
@@ -139,6 +142,7 @@ qjackctlSetup::~qjackctlSetup (void)
     m_settings.writeEntry("/QueryClose",              bQueryClose);
     m_settings.writeEntry("/KeepOnTop",               bKeepOnTop);
     m_settings.writeEntry("/SystemTray",              bSystemTray);
+    m_settings.writeEntry("/DelayedSetup",            bDelayedSetup);
     m_settings.writeEntry("/ServerConfig",            bServerConfig);
     m_settings.writeEntry("/ServerConfigName",        sServerConfigName);
     m_settings.writeEntry("/ServerConfigTemp",        bServerConfigTemp);
@@ -252,6 +256,8 @@ bool qjackctlSetup::loadPreset ( qjackctlPreset& preset, const QString& sPreset
     preset.sOutDevice   = m_settings.readEntry("/OutDevice", QString::null);
     preset.iInChannels  = m_settings.readNumEntry("/InChannels", 0);
     preset.iOutChannels = m_settings.readNumEntry("/OutChannels", 0);
+    preset.iInLatency   = m_settings.readNumEntry("/InLatency", 0);
+    preset.iOutLatency  = m_settings.readNumEntry("/OutLatency", 0);
     preset.iStartDelay  = m_settings.readNumEntry("/StartDelay", 2);
     preset.bVerbose     = m_settings.readBoolEntry("/Verbose", false);
     preset.iPortMax     = m_settings.readNumEntry("/PortMax", 128);
@@ -297,6 +303,8 @@ bool qjackctlSetup::savePreset ( qjackctlPreset& preset, const QString& sPreset
     m_settings.writeEntry("/OutDevice",   preset.sOutDevice);
     m_settings.writeEntry("/InChannels",  preset.iInChannels);
     m_settings.writeEntry("/OutChannels", preset.iOutChannels);
+    m_settings.writeEntry("/InLatency",   preset.iInLatency);
+    m_settings.writeEntry("/OutLatency",  preset.iOutLatency);
     m_settings.writeEntry("/StartDelay",  preset.iStartDelay);
     m_settings.writeEntry("/Verbose",     preset.bVerbose);
     m_settings.writeEntry("/PortMax",     preset.iPortMax);
@@ -492,27 +500,21 @@ void qjackctlSetup::saveComboBoxHistory ( QComboBox *pComboBox, int iLimit )
 
 void qjackctlSetup::loadWidgetGeometry ( QWidget *pWidget )
 {
-    // Try to restore old form window positioning.
-    if (pWidget) {
-        QPoint fpos;
-        QSize  fsize;
-        bool bVisible;
-        m_settings.beginGroup("/Geometry/" + QString(pWidget->name()));
-        fpos.setX(m_settings.readNumEntry("/x", -1));
-        fpos.setY(m_settings.readNumEntry("/y", -1));
-        fsize.setWidth(m_settings.readNumEntry("/width", -1));
-        fsize.setHeight(m_settings.readNumEntry("/height", -1));
-        bVisible = m_settings.readBoolEntry("/visible", false);
-        m_settings.endGroup();
-        if (fpos.x() > 0 && fpos.y() > 0)
-            pWidget->move(fpos);
-        if (fsize.width() > 0 && fsize.height() > 0)
-            pWidget->resize(fsize);
-        else
-            pWidget->adjustSize();
-        if (bVisible)
-            pWidget->show();
-    }
+	// Try to restore old form window positioning.
+	if (pWidget) {
+		QPoint fpos;
+		QSize  fsize;
+		bool bVisible;
+		m_settings.beginGroup("/Geometry/" + QString(pWidget->name()));
+		fpos.setX(m_settings.readNumEntry("/x", -1));
+		fpos.setY(m_settings.readNumEntry("/y", -1));
+		fsize.setWidth(m_settings.readNumEntry("/width", -1));
+		fsize.setHeight(m_settings.readNumEntry("/height", -1));
+		bVisible = m_settings.readBoolEntry("/visible", false);
+		m_settings.endGroup();
+		new qjackctlDelayedSetup(pWidget, fpos, fsize, bVisible,
+			(bDelayedSetup ? 1000 : 0));
+	}
 }
 
 
@@ -538,4 +540,36 @@ void qjackctlSetup::saveWidgetGeometry ( QWidget *pWidget )
 }
 
 
+// Delayed widget setup helper class.
+qjackctlDelayedSetup::qjackctlDelayedSetup ( QWidget *pWidget,
+	const QPoint& pos, const QSize& size, bool bVisible, int iDelay )
+	: m_pos(pos), m_size(size)
+{
+	m_pWidget  = pWidget;
+	m_bVisible = bVisible;
+
+	if (iDelay > 0) {
+		QTimer::singleShot(iDelay, this, SLOT(setup()));
+	} else {
+		setup();
+	}
+}
+
+
+void qjackctlDelayedSetup::setup (void)
+{
+	if (m_pWidget) {
+		if (m_pos.x() > 0 && m_pos.y() > 0)
+			m_pWidget->move(m_pos);
+		if (m_size.width() > 0 && m_size.height() > 0)
+			m_pWidget->resize(m_size);
+		else
+			m_pWidget->adjustSize();
+		if (m_bVisible)
+			m_pWidget->show();
+	}
+	deleteLater();
+}
+
+
 // end of qjackctlSetup.cpp
