@@ -39,6 +39,10 @@ void qjackctlSocketForm::init()
     m_pAddPlugMenu = NULL;
 
     PlugListView->setSorting(-1);
+
+#ifndef CONFIG_ALSA_SEQ
+	MidiRadioButton->setEnabled(false);
+#endif
 }
 
 
@@ -91,6 +95,10 @@ void qjackctlSocketForm::setConnectCount ( int iConnectCount )
 {
     SocketTypeGroup->setEnabled(iConnectCount < 1);
     ExclusiveCheckBox->setEnabled(iConnectCount < 2);
+
+#ifndef CONFIG_ALSA_SEQ
+	MidiRadioButton->setEnabled(false);
+#endif
 }
 
 
@@ -320,15 +328,20 @@ void qjackctlSocketForm::contextMenu( QListViewItem *pItem, const QPoint& pos, i
     QPopupMenu* pContextMenu = new QPopupMenu(this);
 
     bool bEnabled = (pItem != NULL);
-    iItemID = pContextMenu->insertItem(tr("Add Plug"), m_pAddPlugMenu);
-    iItemID = pContextMenu->insertItem(tr("Remove"), this, SLOT(removePlug()));
+    iItemID = pContextMenu->insertItem(QIconSet(QPixmap::fromMimeSource("add1.png")),
+		tr("Add Plug"), m_pAddPlugMenu);
+    iItemID = pContextMenu->insertItem(QIconSet(QPixmap::fromMimeSource("remove1.png")),
+		tr("Remove"), this, SLOT(removePlug()));
     pContextMenu->setItemEnabled(iItemID, bEnabled);
-    iItemID = pContextMenu->insertItem(tr("Edit"), this, SLOT(editPlug()));
+    iItemID = pContextMenu->insertItem(QIconSet(QPixmap::fromMimeSource("edit1.png")),
+		tr("Edit"), this, SLOT(editPlug()));
     pContextMenu->setItemEnabled(iItemID, bEnabled);
     pContextMenu->insertSeparator();
-    iItemID = pContextMenu->insertItem(tr("Move Up"), this, SLOT(moveUpPlug()));
+    iItemID = pContextMenu->insertItem(QIconSet(QPixmap::fromMimeSource("up1.png")),
+		tr("Move Up"), this, SLOT(moveUpPlug()));
     pContextMenu->setItemEnabled(iItemID, (bEnabled && pItem->itemAbove() != NULL));
-    iItemID = pContextMenu->insertItem(tr("Move Down"), this, SLOT(moveDownPlug()));
+    iItemID = pContextMenu->insertItem(QIconSet(QPixmap::fromMimeSource("down1.png")),
+		tr("Move Down"), this, SLOT(moveDownPlug()));
     pContextMenu->setItemEnabled(iItemID, (bEnabled && pItem->nextSibling() != NULL));
 
     pContextMenu->exec(pos);
@@ -384,6 +397,7 @@ void qjackctlSocketForm::socketTypeChanged()
             pXpmSocket = m_ppPixmaps[QJACKCTL_XPM_MIDI_SOCKET];
         SocketTabWidget->setTabIconSet(SocketTabWidget->page(0), QIconSet(*pXpmSocket));
         pXpmPlug = m_ppPixmaps[QJACKCTL_XPM_MIDI_PLUG];
+#ifdef CONFIG_ALSA_SEQ
         if (m_pAlsaSeq) {
             // Readd all subscribers...
             snd_seq_client_info_t *pClientInfo;
@@ -418,6 +432,7 @@ void qjackctlSocketForm::socketTypeChanged()
                 }
             }
         }
+#endif	// CONFIG_ALSA_SEQ
         break;
     }
 
@@ -465,6 +480,7 @@ void qjackctlSocketForm::clientNameChanged()
         }
         break;
       case 1: // QJACKCTL_SOCKETTYPE_MIDI
+#ifdef CONFIG_ALSA_SEQ
         if (m_pAlsaSeq) {
             // Fill sequencer plugs...
             snd_seq_client_info_t *pClientInfo;
@@ -495,6 +511,7 @@ void qjackctlSocketForm::clientNameChanged()
                 }
             }
         }
+#endif	// CONFIG_ALSA_SEQ
         break;
     }
 
